@@ -13,13 +13,13 @@
 
 import Foundation
 
-protocol MediaCategoryViewControllerDelegate: NSObjectProtocol {
+@objc protocol MediaCategoryViewControllerDelegate: NSObjectProtocol {
     func needsToUpdateNavigationbarIfNeeded(_ viewController: MediaCategoryViewController)
     func enableCategorySwitching(for viewController: MediaCategoryViewController,
-                               enable: Bool)
+                                 enable: Bool)
 }
 
-class MediaCategoryViewController: UICollectionViewController, UICollectionViewDelegateFlowLayout, UISearchBarDelegate, IndicatorInfoProvider {
+class MediaCategoryViewController: UICollectionViewController, UISearchBarDelegate, IndicatorInfoProvider {
 
     var model: MediaLibraryBaseModel
     private var services: Services
@@ -31,7 +31,9 @@ class MediaCategoryViewController: UICollectionViewController, UICollectionViewD
     private let searchBarSize: CGFloat = 50.0
     private var rendererButton: UIButton
     private lazy var editController: EditController = {
-        let editController = EditController(mediaLibraryService:services.medialibraryService, model: model)
+        let editController = EditController(mediaLibraryService:services.medialibraryService,
+                                            model: model,
+                                            presentingView: collectionView)
         editController.delegate = self
         return editController
     }()
@@ -64,6 +66,17 @@ class MediaCategoryViewController: UICollectionViewController, UICollectionViewD
         return actionSheet
     }()
 
+    private lazy var sortBarButton: UIBarButtonItem = {
+        return UIBarButtonItem(customView: setupSortButton())
+    }()
+
+    private lazy var editBarButton: UIBarButtonItem = {
+        return setupEditBarButton()
+    }()
+
+    private lazy var rendererBarButton: UIBarButtonItem = {
+        return UIBarButtonItem(customView: rendererButton)
+    }()
 
     lazy var emptyView: VLCEmptyLibraryView = {
         let name = String(describing: VLCEmptyLibraryView.self)
@@ -101,8 +114,8 @@ class MediaCategoryViewController: UICollectionViewController, UICollectionViewD
         if let collection = model as? CollectionModel {
             title = collection.mediaCollection.title()
         }
-        NotificationCenter.default.addObserver(self, selector: #selector(themeDidChange), name: .VLCThemeDidChangeNotification, object: nil)
-        navigationItem.rightBarButtonItems = [editButtonItem, UIBarButtonItem(customView: rendererButton)]
+        NotificationCenter.default.addObserver(self, selector: #selector(themeDidChange),
+                                               name: .VLCThemeDidChangeNotification, object: nil)
     }
 
     func setupSearchBar() {
@@ -146,6 +159,13 @@ class MediaCategoryViewController: UICollectionViewController, UICollectionViewD
         }
     }
 
+    private func updateVideoGroups() {
+        // Manually update video groups since there is no callbacks for it
+        if let videoGroupViewModel = model as? VideoGroupViewModel {
+            videoGroupViewModel.updateVideoGroups()
+        }
+    }
+
     @objc func reloadData() {
         DispatchQueue.main.async {
             [weak self] in
@@ -188,6 +208,7 @@ class MediaCategoryViewController: UICollectionViewController, UICollectionViewD
         manager.presentingViewController = self
         cachedCellSize = .zero
         collectionView.collectionViewLayout.invalidateLayout()
+        updateVideoGroups()
         reloadData()
     }
 
@@ -275,7 +296,7 @@ class MediaCategoryViewController: UICollectionViewController, UICollectionViewD
         collectionView?.dataSource = editing ? editController : self
         collectionView?.delegate = editing ? editController : self
 
-        editController.resetSelections()
+        editController.resetSelections(resetUI: true)
         displayEditToolbar()
 
         PlaybackService.sharedInstance().setPlayerHidden(editing)
@@ -337,7 +358,11 @@ class MediaCategoryViewController: UICollectionViewController, UICollectionViewD
             play(media: media, at: indexPath)
             createSpotlightItem(media: media)
         } else if let mediaCollection = modelContent as? MediaCollectionModel {
-            let collectionViewController = CollectionCategoryViewController(services, mediaCollection: mediaCollection)
+            let collectionViewController = CollectionCategoryViewController(services,
+                                                                            mediaCollection: mediaCollection)
+
+            collectionViewController.navigationItem.rightBarButtonItems = collectionViewController.rightBarButtonItems()
+
             navigationController?.pushViewController(collectionViewController, animated: true)
         }
     }
@@ -356,6 +381,79 @@ class MediaCategoryViewController: UICollectionViewController, UICollectionViewD
     }
 }
 
+// MARK: - NavigationItem
+
+extension MediaCategoryViewController {
+    private func setupEditBarButton() -> UIBarButtonItem {
+        let editButton = UIBarButtonItem(image: UIImage(named: "edit"),
+                                         style: .plain, target: self,
+                                         action: #selector(handleEditing))
+        editButton.tintColor = PresentationTheme.current.colors.orangeUI
+        editButton.accessibilityLabel = NSLocalizedString("BUTTON_EDIT", comment: "")
+        editButton.accessibilityHint = NSLocalizedString("BUTTON_EDIT_HINT", comment: "")
+        return editButton
+    }
+
+    private func setupSortButton() -> UIButton {
+        // Fetch sortButton configuration from MediaVC
+        let sortButton = UIButton(frame: CGRect(x: 0, y: 0, width: 44, height: 44))
+        sortButton.setImage(UIImage(named: "sort"), for: .normal)
+        sortButton.addTarget(self,
+                             action: #selector(handleSort),
+                             for: .touchUpInside)
+        sortButton
+            .addGestureRecognizer(UILongPressGestureRecognizer(target: self,
+                                                               action: #selector(handleSortShortcut)))
+
+        sortButton.tintColor = PresentationTheme.current.colors.orangeUI
+        sortButton.accessibilityLabel = NSLocalizedString("BUTTON_SORT", comment: "")
+        sortButton.accessibilityHint = NSLocalizedString("BUTTON_SORT_HINT", comment: "")
+        return sortButton
+    }
+
+    private func rightBarButtonItems() -> [UIBarButtonItem] {
+        var rightBarButtonItems = [UIBarButtonItem]()
+
+        rightBarButtonItems.append(editBarButton)
+        // Sort is only available for VideoGroups
+        if let model = model as? CollectionModel, model.mediaCollection is VLCMLVideoGroup {
+            rightBarButtonItems.append(sortBarButton)
+        }
+        rightBarButtonItems.append(rendererBarButton)
+        return rightBarButtonItems
+    }
+
+    @objc func handleSort() {
+        var currentSortIndex: Int = 0
+        for (index, criteria) in
+            model.sortModel.sortingCriteria.enumerated()
+            where criteria == model.sortModel.currentSort {
+                currentSortIndex = index
+                break
+        }
+        present(sortActionSheet, animated: false) {
+            [sortActionSheet, currentSortIndex] in
+            sortActionSheet.collectionView.selectItem(at:
+                IndexPath(row: currentSortIndex, section: 0), animated: false,
+                                                              scrollPosition: .centeredVertically)
+        }
+    }
+
+    @objc func handleSortShortcut() {
+        model.sort(by: model.sortModel.currentSort, desc: !model.sortModel.desc)
+    }
+
+    @objc func handleEditing() {
+        isEditing = !isEditing
+        setEditing(isEditing, animated: true)
+        navigationItem.rightBarButtonItems = isEditing ? [UIBarButtonItem(barButtonSystemItem: .done,
+                                                                          target: self,
+                                                                          action: #selector(handleEditing))]
+            : rightBarButtonItems()
+        navigationItem.setHidesBackButton(isEditing, animated: true)
+    }
+}
+
 // MARK: - UISearchBarDelegate
 
 extension MediaCategoryViewController {
@@ -393,7 +491,7 @@ extension MediaCategoryViewController {
 
 // MARK: - UICollectionViewDelegateFlowLayout
 
-extension MediaCategoryViewController {
+extension MediaCategoryViewController: UICollectionViewDelegateFlowLayout {
     func collectionView(_ collectionView: UICollectionView, layout collectionViewLayout: UICollectionViewLayout, sizeForItemAt indexPath: IndexPath) -> CGSize {
         if cachedCellSize == .zero {
             //For iOS 10 when rotating we take the value from willTransition to size, for the first layout pass that value is 0 though,
@@ -424,26 +522,6 @@ extension MediaCategoryViewController {
     func collectionView(_ collectionView: UICollectionView, layout collectionViewLayout: UICollectionViewLayout, minimumInteritemSpacingForSectionAt section: Int) -> CGFloat {
         return model.cellType.interItemPadding
     }
-
-    func handleSort() {
-        var currentSortIndex: Int = 0
-        for (index, criteria) in
-            model.sortModel.sortingCriteria.enumerated()
-            where criteria == model.sortModel.currentSort {
-                currentSortIndex = index
-                break
-        }
-        present(sortActionSheet, animated: false) {
-            [sortActionSheet, currentSortIndex] in
-            sortActionSheet.collectionView.selectItem(at:
-                IndexPath(row: currentSortIndex, section: 0), animated: false,
-                                                    scrollPosition: .centeredVertically)
-        }
-    }
-
-    func handleSortShortcut() {
-        model.sort(by: model.sortModel.currentSort, desc: !model.sortModel.desc)
-    }
 }
 
 // MARK: VLCActionSheetDelegate
@@ -524,6 +602,7 @@ private extension MediaCategoryViewController {
             let editCellNib = UINib(nibName: editCell.nibName, bundle: nil)
             collectionView?.register(editCellNib, forCellWithReuseIdentifier: editCell.defaultReuseIdentifier)
         }
+        collectionView.allowsMultipleSelection = true
         collectionView?.backgroundColor = PresentationTheme.current.colors.background
         collectionView?.alwaysBounceVertical = true
         longPressGesture = UILongPressGestureRecognizer(target: self, action: #selector(self.handleLongGesture(gesture:)))
