@@ -39,6 +39,8 @@ class MediaEditCell: BaseCollectionViewCell {
                 updateForGenre(genre: genre)
             } else if let playlist = media as? VLCMLPlaylist {
                 updateForPlaylist(playlist: playlist)
+            } else if let videoGroup = media as? VLCMLVideoGroup {
+                update(videoGroup: videoGroup)
             } else {
                 assertionFailure("MediaEditCell: media: Needs to be of a supported Type.")
             }
@@ -120,9 +122,20 @@ class MediaEditCell: BaseCollectionViewCell {
         thumbnailImageView.image = playlist.thumbnail()
     }
 
-    var isChecked: Bool = false {
-         didSet {
-            checkboxImageView.image = isChecked ? UIImage(named: "checkboxSelected") : UIImage(named: "checkboxEmpty")
+    func update(videoGroup: VLCMLVideoGroup) {
+        thumbnailImageView.layer.cornerRadius = 3
+        AudioAspectRatio.isActive = false
+        VideoAspectRatio.isActive = true
+        titleLabel.text = videoGroup.name()
+        accessibilityLabel = videoGroup.accessibilityText()
+        timeLabel.text = videoGroup.numberOfTracksString()
+        thumbnailImageView.image = videoGroup.thumbnail()
+    }
+
+    override var isSelected: Bool {
+        didSet {
+            checkboxImageView.image = isSelected ? UIImage(named: "checkboxSelected")
+                : UIImage(named: "checkboxEmpty")
         }
     }
 
@@ -157,7 +170,7 @@ class MediaEditCell: BaseCollectionViewCell {
         sizeLabel.text = ""
         accessibilityLabel = ""
         thumbnailImageView.image = nil
-        isChecked = false
+        isSelected = false
         thumbnailImageView.layer.cornerRadius = 0
         AudioAspectRatio.isActive = true
         VideoAspectRatio.isActive = false
