@@ -73,7 +73,7 @@ typedef NS_ENUM(NSInteger, VLCPanType) {
     BOOL _volumeGestureEnabled;
     BOOL _playPauseGestureEnabled;
     BOOL _brightnessGestureEnabled;
-    BOOL _seekGestureEnabled;
+    BOOL _swipeSeekGestureEnabled;
     BOOL _closeGestureEnabled;
     BOOL _variableJumpDurationEnabled;
     BOOL _playbackWillClose;
@@ -654,7 +654,7 @@ typedef NS_ENUM(NSInteger, VLCPanType) {
     _volumeGestureEnabled = [[defaults objectForKey:kVLCSettingVolumeGesture] boolValue];
     _playPauseGestureEnabled = [[defaults objectForKey:kVLCSettingPlayPauseGesture] boolValue];
     _brightnessGestureEnabled = [[defaults objectForKey:kVLCSettingBrightnessGesture] boolValue];
-    _seekGestureEnabled = [[defaults objectForKey:kVLCSettingSeekGesture] boolValue];
+    _swipeSeekGestureEnabled = [[defaults objectForKey:kVLCSettingSeekGesture] boolValue];
     _closeGestureEnabled = [[defaults objectForKey:kVLCSettingCloseGesture] boolValue];
     _variableJumpDurationEnabled = [[defaults objectForKey:kVLCSettingVariableJumpDuration] boolValue];
 }
@@ -1642,7 +1642,7 @@ currentMediaHasTrackToChooseFrom:(BOOL)currentMediaHasTrackToChooseFrom
     
     switch (_currentPanType) {
         case VLCPanTypeSeek: {
-            if (!_seekGestureEnabled)
+            if (!_swipeSeekGestureEnabled)
                 return;
             double timeRemainingDouble = (-[_vpc remainingTime].intValue*0.001);
             int timeRemaining = timeRemainingDouble;
@@ -1724,7 +1724,7 @@ currentMediaHasTrackToChooseFrom:(BOOL)currentMediaHasTrackToChooseFrom
 
 - (void)swipeRecognized:(UISwipeGestureRecognizer*)swipeRecognizer
 {
-    if (!_seekGestureEnabled)
+    if (!_swipeSeekGestureEnabled)
         return;
 
     NSString *hudString = @" ";
@@ -1807,9 +1807,6 @@ currentMediaHasTrackToChooseFrom:(BOOL)currentMediaHasTrackToChooseFrom
 
 - (void)doubleTapRecognized:(UITapGestureRecognizer *)tapRecognizer
 {
-    if (!_seekGestureEnabled)
-        return;
-
     CGFloat screenWidth = self.view.frame.size.width;
     CGFloat backwardBoundary = screenWidth / 3.0;
     CGFloat forwardBoundary = 2 * screenWidth / 3.0;
@@ -1956,10 +1953,10 @@ currentMediaHasTrackToChooseFrom:(BOOL)currentMediaHasTrackToChooseFrom
     [_playingExternalView shouldDisplay:displayExternally movieView:_movieView];
     _artworkImageView.hidden = displayExternally;
 
-    if (displayExternally) {
-        // Adjust constraints for external display
-        UIView *displayView = _playingExternalView.displayView;
+    UIView *displayView = _playingExternalView.displayView;
 
+    if (displayExternally && _movieView.superview == displayView) {
+        // Adjust constraints for external display
         [NSLayoutConstraint activateConstraints:@[
             [_movieView.leadingAnchor constraintEqualToAnchor:displayView.leadingAnchor],
             [_movieView.trailingAnchor constraintEqualToAnchor:displayView.trailingAnchor],
